# Synthetic seismograms in 2-D model UNCONFORMITY
# ===============================================

# Basic version of the data to calculate synthetic seismograms
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Input files required:
 #chk.pl: "model/u2d/"  "u2d-mod.dat"
 #chk.pl: "crt/u2d/"    "u2d-src.dat"
 #chk.pl: "crt/u2d/"    "u2d-rec.dat"
 #chk.pl: "crt/u2d/"    "u2d-crt.dat"
 #chk.pl: "crt/u2d/"    "u2d-rpa.dat"
 #chk.pl: "crt/u2d/"    "u2d-wri.dat"
 #chk.pl: "crt/"        "source.dat"

# Model UNCONFORMITY (Cormier and Mellen 1984)
  MODEL='u2d-mod.dat'

# Source and receivers
  SRC='u2d-src.dat'  REC='u2d-rec.dat'

# Data filenames for CRT (for details see 'crt.for')
  DCRT='u2d-crt.dat'
  CODE='u2d-crt.dat'
  RPAR='u2d-rpa.dat'
  WRIT='u2d-wri.dat'
  CRTLOG='u2d-log.out'

# Kind of ray parameters (for details see 'init.for')
  INIPAR=2  # geographic-like spherical coordinates

# Reference frequency for the attenuation
  TIMUL=1  FREF=100

# Data describing the source time function
  KSIG=1 # (Gabor signal)
  SIGT=0.  SIGF=100.  SIGW=4.  SIGPH=0.
  SIGA=258.174 # (258.174=12*pi*rho*v**3)

# Data describing the filtration of the source time function
  FMIN=4.  FLOW=20.  FHIGH=184.  FMAX=200. # (cosine filter)

# Time step and time interval for the Fast Fourier Transform
  DT=0.001  NFFT=1024

# Data to control optional plotting of program SS
  SIGPLOT='u2d-sig.ps'  MPTS=100

# GSE file with synthetic seismograms
  SS='u2d-ss.gse'

# Data to control seismogram plotting (program SP)
  SP1='u2d-ss1.ps'  SP2=' '  SP3='u2d-ss3.ps'
  KODESP=3  SPCHRH=0.23
  SPTMIN=0.300  SPTMAX=1.300   SPTLEN=16.00  SPTDIV=10  SPTSUB=1
  SPXMIN=0.136  SPXMAX=-1.241  SPXLEN=13.77  SPXDIV=9   SPXSUB=3
  NORMSP=1  SPAMP=-2.00

# Programs to execute
  crt:     'u2d-ss.h' /       # two-point ray tracing
                              # (do not link 'crt.for' with 'scropc.for'!)
  green:   'u2d-ss.h' /       # Green function
 #greenss: 'u2d-ss.h' /       # response function
 #ss:      'u2d-ss.h' /       # synthetic seismograms
 #sp:      'u2d-ss.h' /       # seismogram plotting

# Four modifications of the above data
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Time-domain calculation (no attenuation available)
  SIGGSE='u2d-sig.gse' SS=' '
  ss:      'u2d-ss.h' /       # source time function
  TIMUL=0  FREF=100  SS='u2d-t.gse'
  greenss: 'u2d-ss.h' /       # synthetic seismograms
  SIGGSE=' '
  SP1='u2d-t1.ps'  SP2=' '  SP3='u2d-t3.ps'  SPAMP=-0.50
  sp:      'u2d-ss.h' /       # seismogram plotting

# No attenuation (frequency-domain calculation)
  TIMUL=0  FREF=100
  SS='u2d-f.gse'
  SP1='u2d-f1.ps'  SP2=' '  SP3='u2d-f3.ps'  SPAMP=-0.50
  greenss: 'u2d-ss.h' /       # response function
  ss:      'u2d-ss.h' /       # synthetic seismograms
  sp:      'u2d-ss.h' /       # seismogram plotting

# Noncausal attenuation
  TIMUL=1  FREF=0
  SS='u2d-n.gse'
  SP1='u2d-n1.ps'  SP2=' '  SP3='u2d-n3.ps'  SPAMP=-2.00
  greenss: 'u2d-ss.h' /       # response function
  ss:      'u2d-ss.h' /       # synthetic seismograms
  sp:      'u2d-ss.h' /       # seismogram plotting

# Causal attenuation (equivalent to the basic data)
  TIMUL=1  FREF=100
  SS='u2d-q.gse'
  SP1='u2d-q1.ps'  SP2=' '  SP3='u2d-q3.ps'  SPAMP=-2.00
  greenss: 'u2d-ss.h' /       # response function
  ss:      'u2d-ss.h' /       # synthetic seismograms
  sp:      'u2d-ss.h' /       # seismogram plotting

#=======================================================================
# Comments:
# ~~~~~~~~~
# Temporary files (may be deleted):
# '*.tmp'
# 'r0*.out'
# 's0*.out'
#
# List of output PostScript figures (synthetic seismograms):
# 'u2d-t1.ps'  Time-domain, no attenuation, 1st component
# 'u2d-t3.ps'  Time-domain, no attenuation, 3rd component
# 'u2d-f1.ps'  Frequency-domain, no attenuation, 1st component
# 'u2d-f3.ps'  Frequency-domain, no attenuation, 3rd component
# 'u2d-n1.ps'  Frequency-domain, noncausal attenuation, 1st component
# 'u2d-n3.ps'  Frequency-domain, noncausal attenuation, 3rd component
# 'u2d-q1.ps'  Frequency-domain, attenuation, 1st component
# 'u2d-q3.ps'  Frequency-domain, attenuation, 3rd component
# and
# 'u2d-sig.ps' Sketch of the source time function (output of 'ss.for')
#
# Note:
# In the output PostScript files 'u2d-*.ps' of the 'sp' program, the
# Setup section may be edited in the following way:
#  .48 setlinewidth 1 setlinecap 1 setlinejoin
# For the dvips TeX driver, line
# %%BoundingBox: (atend)
# should be replaced with the %%BoundingBox line from the %%Trailer of
# the PostScript file.
